Rename YV12 to I420.

Change-Id: I453b7044bf46950ef67091f3417ed3e6a65086a0
diff --git a/libvideoeditor/lvpp/Android.mk b/libvideoeditor/lvpp/Android.mk
index 7478ba5..fdcd316 100755
--- a/libvideoeditor/lvpp/Android.mk
+++ b/libvideoeditor/lvpp/Android.mk
@@ -37,7 +37,7 @@
     AudioPlayerBase.cpp \
     PreviewPlayerBase.cpp \
     PreviewRenderer.cpp \
-    YV12ColorConverter.cpp \
+    I420ColorConverter.cpp \
     NativeWindowRenderer.cpp
 
 LOCAL_MODULE_TAGS := optional
diff --git a/libvideoeditor/lvpp/YV12ColorConverter.cpp b/libvideoeditor/lvpp/I420ColorConverter.cpp
similarity index 62%
rename from libvideoeditor/lvpp/YV12ColorConverter.cpp
rename to libvideoeditor/lvpp/I420ColorConverter.cpp
index 07fa063..75f1e93 100755
--- a/libvideoeditor/lvpp/YV12ColorConverter.cpp
+++ b/libvideoeditor/lvpp/I420ColorConverter.cpp
@@ -14,41 +14,41 @@
  * limitations under the License.
  */
 
-#include <YV12ColorConverter.h>
+#include <I420ColorConverter.h>
 #include <cutils/log.h>
 #include <dlfcn.h>
 
-YV12ColorConverter::YV12ColorConverter() {
+I420ColorConverter::I420ColorConverter() {
     // Open the shared library
-    mHandle = dlopen("libyv12colorconvert.so", RTLD_NOW);
+    mHandle = dlopen("libI420colorconvert.so", RTLD_NOW);
 
     if (mHandle == NULL) {
-        LOGW("YV12ColorConverter: cannot load libyv12colorconvert.so");
+        LOGW("I420ColorConverter: cannot load libI420colorconvert.so");
         return;
     }
 
     // Find the entry point
-    void (*getYV12ColorConverter)(YV12ColorConverter *converter) =
-        (void (*)(YV12ColorConverter*)) dlsym(mHandle, "getYV12ColorConverter");
+    void (*getI420ColorConverter)(I420ColorConverter *converter) =
+        (void (*)(I420ColorConverter*)) dlsym(mHandle, "getI420ColorConverter");
 
-    if (getYV12ColorConverter == NULL) {
-        LOGW("YV12ColorConverter: cannot load getYV12ColorConverter");
+    if (getI420ColorConverter == NULL) {
+        LOGW("I420ColorConverter: cannot load getI420ColorConverter");
         dlclose(mHandle);
         mHandle = NULL;
         return;
     }
 
     // Fill the function pointers.
-    getYV12ColorConverter(this);
+    getI420ColorConverter(this);
 
-    LOGI("YV12ColorConverter: libyv12colorconvert.so loaded");
+    LOGI("I420ColorConverter: libI420colorconvert.so loaded");
 }
 
-bool YV12ColorConverter::isLoaded() {
+bool I420ColorConverter::isLoaded() {
     return mHandle != NULL;
 }
 
-YV12ColorConverter::~YV12ColorConverter() {
+I420ColorConverter::~I420ColorConverter() {
     if (mHandle) {
         dlclose(mHandle);
     }
diff --git a/libvideoeditor/lvpp/NativeWindowRenderer.cpp b/libvideoeditor/lvpp/NativeWindowRenderer.cpp
index cde8b89..23d9506 100755
--- a/libvideoeditor/lvpp/NativeWindowRenderer.cpp
+++ b/libvideoeditor/lvpp/NativeWindowRenderer.cpp
@@ -409,12 +409,12 @@
     // Copy the buffer
     uint8_t* img = NULL;
     buf->lock(GRALLOC_USAGE_SW_WRITE_OFTEN, (void**)(&img));
-    copyYV12Buffer(buffer, img, width, height, buf->getStride());
+    copyI420Buffer(buffer, img, width, height, buf->getStride());
     buf->unlock();
     CHECK(NO_ERROR == anw->queueBuffer(anw, buf->getNativeBuffer()));
 }
 
-void NativeWindowRenderer::copyYV12Buffer(MediaBuffer* src, uint8_t* dst,
+void NativeWindowRenderer::copyI420Buffer(MediaBuffer* src, uint8_t* dst,
         int srcWidth, int srcHeight, int stride) {
     int strideUV = (stride / 2 + 0xf) & ~0xf;
     uint8_t* p = (uint8_t*)src->data() + src->range_offset();
diff --git a/libvideoeditor/lvpp/NativeWindowRenderer.h b/libvideoeditor/lvpp/NativeWindowRenderer.h
index 2af19a3..cafd6fb 100755
--- a/libvideoeditor/lvpp/NativeWindowRenderer.h
+++ b/libvideoeditor/lvpp/NativeWindowRenderer.h
@@ -76,7 +76,7 @@
     void queueInternalBuffer(ANativeWindow* anw, MediaBuffer* buffer);
     void queueExternalBuffer(ANativeWindow* anw, MediaBuffer* buffer,
             int width, int height);
-    void copyYV12Buffer(MediaBuffer* src, uint8_t* dst,
+    void copyI420Buffer(MediaBuffer* src, uint8_t* dst,
             int srcWidth, int srcHeight, int stride);
     void updateProgramAndHandle(uint32_t videoEffect);
     void calculatePositionCoordinates(M4xVSS_MediaRendering renderingMode,
diff --git a/libvideoeditor/lvpp/YV12ColorConverter.h b/libvideoeditor/lvpp/I420ColorConverter.h
similarity index 67%
rename from libvideoeditor/lvpp/YV12ColorConverter.h
rename to libvideoeditor/lvpp/I420ColorConverter.h
index 32b52f7..8d48e44 100755
--- a/libvideoeditor/lvpp/YV12ColorConverter.h
+++ b/libvideoeditor/lvpp/I420ColorConverter.h
@@ -14,17 +14,17 @@
  * limitations under the License.
  */
 
-#ifndef YV12_COLOR_CONVERTER_H
-#define YV12_COLOR_CONVERTER_H
+#ifndef I420_COLOR_CONVERTER_H
+#define I420_COLOR_CONVERTER_H
 
-#include <IYV12ColorConverter.h>
+#include <II420ColorConverter.h>
 
-// This is a wrapper around the YV12 color converter functions in
-// IYV12ColorConverter, which is loaded from a shared library.
-class YV12ColorConverter: public IYV12ColorConverter {
+// This is a wrapper around the I420 color converter functions in
+// II420ColorConverter, which is loaded from a shared library.
+class I420ColorConverter: public II420ColorConverter {
 public:
-    YV12ColorConverter();
-    ~YV12ColorConverter();
+    I420ColorConverter();
+    ~I420ColorConverter();
 
     // Returns true if the converter functions are successfully loaded.
     bool isLoaded();
@@ -32,4 +32,4 @@
     void* mHandle;
 };
 
-#endif /* YV12_COLOR_CONVERTER_H */
+#endif /* I420_COLOR_CONVERTER_H */